# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/user_lists.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import customer_match_upload_key_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2
from google.ads.google_ads.v2.proto.enums import user_list_combined_rule_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__combined__rule__operator__pb2
from google.ads.google_ads.v2.proto.enums import user_list_crm_data_source_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2
from google.ads.google_ads.v2.proto.enums import user_list_date_rule_item_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__date__rule__item__operator__pb2
from google.ads.google_ads.v2.proto.enums import user_list_logical_rule_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__logical__rule__operator__pb2
from google.ads.google_ads.v2.proto.enums import user_list_number_rule_item_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__number__rule__item__operator__pb2
from google.ads.google_ads.v2.proto.enums import user_list_prepopulation_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__prepopulation__status__pb2
from google.ads.google_ads.v2.proto.enums import user_list_rule_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__rule__type__pb2
from google.ads.google_ads.v2.proto.enums import user_list_string_rule_item_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__string__rule__item__operator__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/user_lists.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\016UserListsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n5google/ads/googleads_v2/proto/common/user_lists.proto\x12\x1egoogle.ads.googleads.v2.common\x1aHgoogle/ads/googleads_v2/proto/enums/customer_match_upload_key_type.proto\x1aJgoogle/ads/googleads_v2/proto/enums/user_list_combined_rule_operator.proto\x1aHgoogle/ads/googleads_v2/proto/enums/user_list_crm_data_source_type.proto\x1aKgoogle/ads/googleads_v2/proto/enums/user_list_date_rule_item_operator.proto\x1aIgoogle/ads/googleads_v2/proto/enums/user_list_logical_rule_operator.proto\x1aMgoogle/ads/googleads_v2/proto/enums/user_list_number_rule_item_operator.proto\x1aHgoogle/ads/googleads_v2/proto/enums/user_list_prepopulation_status.proto\x1a=google/ads/googleads_v2/proto/enums/user_list_rule_type.proto\x1aMgoogle/ads/googleads_v2/proto/enums/user_list_string_rule_item_operator.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"K\n\x13SimilarUserListInfo\x12\x34\n\x0eseed_user_list\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa9\x02\n\x14\x43rmBasedUserListInfo\x12,\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12q\n\x0fupload_key_type\x18\x02 \x01(\x0e\x32X.google.ads.googleads.v2.enums.CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType\x12p\n\x10\x64\x61ta_source_type\x18\x03 \x01(\x0e\x32V.google.ads.googleads.v2.enums.UserListCrmDataSourceTypeEnum.UserListCrmDataSourceType\"\xc0\x01\n\x10UserListRuleInfo\x12W\n\trule_type\x18\x01 \x01(\x0e\x32\x44.google.ads.googleads.v2.enums.UserListRuleTypeEnum.UserListRuleType\x12S\n\x10rule_item_groups\x18\x02 \x03(\x0b\x32\x39.google.ads.googleads.v2.common.UserListRuleItemGroupInfo\"e\n\x19UserListRuleItemGroupInfo\x12H\n\nrule_items\x18\x01 \x03(\x0b\x32\x34.google.ads.googleads.v2.common.UserListRuleItemInfo\"\xd3\x02\n\x14UserListRuleItemInfo\x12*\n\x04name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12V\n\x10number_rule_item\x18\x02 \x01(\x0b\x32:.google.ads.googleads.v2.common.UserListNumberRuleItemInfoH\x00\x12V\n\x10string_rule_item\x18\x03 \x01(\x0b\x32:.google.ads.googleads.v2.common.UserListStringRuleItemInfoH\x00\x12R\n\x0e\x64\x61te_rule_item\x18\x04 \x01(\x0b\x32\x38.google.ads.googleads.v2.common.UserListDateRuleItemInfoH\x00\x42\x0b\n\trule_item\"\xec\x01\n\x18UserListDateRuleItemInfo\x12n\n\x08operator\x18\x01 \x01(\x0e\x32\\.google.ads.googleads.v2.enums.UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperator\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\x0eoffset_in_days\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xbd\x01\n\x1aUserListNumberRuleItemInfo\x12r\n\x08operator\x18\x01 \x01(\x0e\x32`.google.ads.googleads.v2.enums.UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xbd\x01\n\x1aUserListStringRuleItemInfo\x12r\n\x08operator\x18\x01 \x01(\x0e\x32`.google.ads.googleads.v2.enums.UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa0\x02\n\x18\x43ombinedRuleUserListInfo\x12\x46\n\x0cleft_operand\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserListRuleInfo\x12G\n\rright_operand\x18\x02 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserListRuleInfo\x12s\n\rrule_operator\x18\x03 \x01(\x0e\x32\\.google.ads.googleads.v2.enums.UserListCombinedRuleOperatorEnum.UserListCombinedRuleOperator\"\xc0\x01\n\x1c\x44\x61teSpecificRuleUserListInfo\x12>\n\x04rule\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserListRuleInfo\x12\x30\n\nstart_date\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\\\n\x1a\x45xpressionRuleUserListInfo\x12>\n\x04rule\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserListRuleInfo\"\xcd\x03\n\x15RuleBasedUserListInfo\x12x\n\x14prepopulation_status\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.UserListPrepopulationStatusEnum.UserListPrepopulationStatus\x12[\n\x17\x63ombined_rule_user_list\x18\x02 \x01(\x0b\x32\x38.google.ads.googleads.v2.common.CombinedRuleUserListInfoH\x00\x12\x64\n\x1c\x64\x61te_specific_rule_user_list\x18\x03 \x01(\x0b\x32<.google.ads.googleads.v2.common.DateSpecificRuleUserListInfoH\x00\x12_\n\x19\x65xpression_rule_user_list\x18\x04 \x01(\x0b\x32:.google.ads.googleads.v2.common.ExpressionRuleUserListInfoH\x00\x42\x16\n\x14rule_based_user_list\"]\n\x13LogicalUserListInfo\x12\x46\n\x05rules\x18\x01 \x03(\x0b\x32\x37.google.ads.googleads.v2.common.UserListLogicalRuleInfo\"\xda\x01\n\x17UserListLogicalRuleInfo\x12l\n\x08operator\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperator\x12Q\n\rrule_operands\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v2.common.LogicalUserListOperandInfo\"M\n\x1aLogicalUserListOperandInfo\x12/\n\tuser_list\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"X\n\x11\x42\x61sicUserListInfo\x12\x43\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x32.google.ads.googleads.v2.common.UserListActionInfo\"\x9f\x01\n\x12UserListActionInfo\x12\x39\n\x11\x63onversion_action\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12:\n\x12remarketing_action\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x42\x12\n\x10user_list_actionB\xe9\x01\n\"com.google.ads.googleads.v2.commonB\x0eUserListsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__combined__rule__operator__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__date__rule__item__operator__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__logical__rule__operator__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__number__rule__item__operator__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__prepopulation__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__rule__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__string__rule__item__operator__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_SIMILARUSERLISTINFO = _descriptor.Descriptor(
  name='SimilarUserListInfo',
  full_name='google.ads.googleads.v2.common.SimilarUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seed_user_list', full_name='google.ads.googleads.v2.common.SimilarUserListInfo.seed_user_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=897,
)


_CRMBASEDUSERLISTINFO = _descriptor.Descriptor(
  name='CrmBasedUserListInfo',
  full_name='google.ads.googleads.v2.common.CrmBasedUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v2.common.CrmBasedUserListInfo.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_key_type', full_name='google.ads.googleads.v2.common.CrmBasedUserListInfo.upload_key_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='google.ads.googleads.v2.common.CrmBasedUserListInfo.data_source_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=1197,
)


_USERLISTRULEINFO = _descriptor.Descriptor(
  name='UserListRuleInfo',
  full_name='google.ads.googleads.v2.common.UserListRuleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_type', full_name='google.ads.googleads.v2.common.UserListRuleInfo.rule_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_item_groups', full_name='google.ads.googleads.v2.common.UserListRuleInfo.rule_item_groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1200,
  serialized_end=1392,
)


_USERLISTRULEITEMGROUPINFO = _descriptor.Descriptor(
  name='UserListRuleItemGroupInfo',
  full_name='google.ads.googleads.v2.common.UserListRuleItemGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_items', full_name='google.ads.googleads.v2.common.UserListRuleItemGroupInfo.rule_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1495,
)


_USERLISTRULEITEMINFO = _descriptor.Descriptor(
  name='UserListRuleItemInfo',
  full_name='google.ads.googleads.v2.common.UserListRuleItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_rule_item', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.number_rule_item', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_rule_item', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.string_rule_item', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_rule_item', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.date_rule_item', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule_item', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.rule_item',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1498,
  serialized_end=1837,
)


_USERLISTDATERULEITEMINFO = _descriptor.Descriptor(
  name='UserListDateRuleItemInfo',
  full_name='google.ads.googleads.v2.common.UserListDateRuleItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.common.UserListDateRuleItemInfo.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v2.common.UserListDateRuleItemInfo.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_in_days', full_name='google.ads.googleads.v2.common.UserListDateRuleItemInfo.offset_in_days', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1840,
  serialized_end=2076,
)


_USERLISTNUMBERRULEITEMINFO = _descriptor.Descriptor(
  name='UserListNumberRuleItemInfo',
  full_name='google.ads.googleads.v2.common.UserListNumberRuleItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.common.UserListNumberRuleItemInfo.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v2.common.UserListNumberRuleItemInfo.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2079,
  serialized_end=2268,
)


_USERLISTSTRINGRULEITEMINFO = _descriptor.Descriptor(
  name='UserListStringRuleItemInfo',
  full_name='google.ads.googleads.v2.common.UserListStringRuleItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.common.UserListStringRuleItemInfo.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v2.common.UserListStringRuleItemInfo.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2271,
  serialized_end=2460,
)


_COMBINEDRULEUSERLISTINFO = _descriptor.Descriptor(
  name='CombinedRuleUserListInfo',
  full_name='google.ads.googleads.v2.common.CombinedRuleUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_operand', full_name='google.ads.googleads.v2.common.CombinedRuleUserListInfo.left_operand', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_operand', full_name='google.ads.googleads.v2.common.CombinedRuleUserListInfo.right_operand', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_operator', full_name='google.ads.googleads.v2.common.CombinedRuleUserListInfo.rule_operator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2463,
  serialized_end=2751,
)


_DATESPECIFICRULEUSERLISTINFO = _descriptor.Descriptor(
  name='DateSpecificRuleUserListInfo',
  full_name='google.ads.googleads.v2.common.DateSpecificRuleUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule', full_name='google.ads.googleads.v2.common.DateSpecificRuleUserListInfo.rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='google.ads.googleads.v2.common.DateSpecificRuleUserListInfo.start_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='google.ads.googleads.v2.common.DateSpecificRuleUserListInfo.end_date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2754,
  serialized_end=2946,
)


_EXPRESSIONRULEUSERLISTINFO = _descriptor.Descriptor(
  name='ExpressionRuleUserListInfo',
  full_name='google.ads.googleads.v2.common.ExpressionRuleUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule', full_name='google.ads.googleads.v2.common.ExpressionRuleUserListInfo.rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2948,
  serialized_end=3040,
)


_RULEBASEDUSERLISTINFO = _descriptor.Descriptor(
  name='RuleBasedUserListInfo',
  full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prepopulation_status', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.prepopulation_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combined_rule_user_list', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.combined_rule_user_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_specific_rule_user_list', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.date_specific_rule_user_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expression_rule_user_list', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.expression_rule_user_list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule_based_user_list', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.rule_based_user_list',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3043,
  serialized_end=3504,
)


_LOGICALUSERLISTINFO = _descriptor.Descriptor(
  name='LogicalUserListInfo',
  full_name='google.ads.googleads.v2.common.LogicalUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='google.ads.googleads.v2.common.LogicalUserListInfo.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3506,
  serialized_end=3599,
)


_USERLISTLOGICALRULEINFO = _descriptor.Descriptor(
  name='UserListLogicalRuleInfo',
  full_name='google.ads.googleads.v2.common.UserListLogicalRuleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.common.UserListLogicalRuleInfo.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_operands', full_name='google.ads.googleads.v2.common.UserListLogicalRuleInfo.rule_operands', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3602,
  serialized_end=3820,
)


_LOGICALUSERLISTOPERANDINFO = _descriptor.Descriptor(
  name='LogicalUserListOperandInfo',
  full_name='google.ads.googleads.v2.common.LogicalUserListOperandInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_list', full_name='google.ads.googleads.v2.common.LogicalUserListOperandInfo.user_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3822,
  serialized_end=3899,
)


_BASICUSERLISTINFO = _descriptor.Descriptor(
  name='BasicUserListInfo',
  full_name='google.ads.googleads.v2.common.BasicUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='google.ads.googleads.v2.common.BasicUserListInfo.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3901,
  serialized_end=3989,
)


_USERLISTACTIONINFO = _descriptor.Descriptor(
  name='UserListActionInfo',
  full_name='google.ads.googleads.v2.common.UserListActionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.common.UserListActionInfo.conversion_action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remarketing_action', full_name='google.ads.googleads.v2.common.UserListActionInfo.remarketing_action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='user_list_action', full_name='google.ads.googleads.v2.common.UserListActionInfo.user_list_action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3992,
  serialized_end=4151,
)

_SIMILARUSERLISTINFO.fields_by_name['seed_user_list'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRMBASEDUSERLISTINFO.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRMBASEDUSERLISTINFO.fields_by_name['upload_key_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2._CUSTOMERMATCHUPLOADKEYTYPEENUM_CUSTOMERMATCHUPLOADKEYTYPE
_CRMBASEDUSERLISTINFO.fields_by_name['data_source_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2._USERLISTCRMDATASOURCETYPEENUM_USERLISTCRMDATASOURCETYPE
_USERLISTRULEINFO.fields_by_name['rule_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__rule__type__pb2._USERLISTRULETYPEENUM_USERLISTRULETYPE
_USERLISTRULEINFO.fields_by_name['rule_item_groups'].message_type = _USERLISTRULEITEMGROUPINFO
_USERLISTRULEITEMGROUPINFO.fields_by_name['rule_items'].message_type = _USERLISTRULEITEMINFO
_USERLISTRULEITEMINFO.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTRULEITEMINFO.fields_by_name['number_rule_item'].message_type = _USERLISTNUMBERRULEITEMINFO
_USERLISTRULEITEMINFO.fields_by_name['string_rule_item'].message_type = _USERLISTSTRINGRULEITEMINFO
_USERLISTRULEITEMINFO.fields_by_name['date_rule_item'].message_type = _USERLISTDATERULEITEMINFO
_USERLISTRULEITEMINFO.oneofs_by_name['rule_item'].fields.append(
  _USERLISTRULEITEMINFO.fields_by_name['number_rule_item'])
_USERLISTRULEITEMINFO.fields_by_name['number_rule_item'].containing_oneof = _USERLISTRULEITEMINFO.oneofs_by_name['rule_item']
_USERLISTRULEITEMINFO.oneofs_by_name['rule_item'].fields.append(
  _USERLISTRULEITEMINFO.fields_by_name['string_rule_item'])
_USERLISTRULEITEMINFO.fields_by_name['string_rule_item'].containing_oneof = _USERLISTRULEITEMINFO.oneofs_by_name['rule_item']
_USERLISTRULEITEMINFO.oneofs_by_name['rule_item'].fields.append(
  _USERLISTRULEITEMINFO.fields_by_name['date_rule_item'])
_USERLISTRULEITEMINFO.fields_by_name['date_rule_item'].containing_oneof = _USERLISTRULEITEMINFO.oneofs_by_name['rule_item']
_USERLISTDATERULEITEMINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__date__rule__item__operator__pb2._USERLISTDATERULEITEMOPERATORENUM_USERLISTDATERULEITEMOPERATOR
_USERLISTDATERULEITEMINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTDATERULEITEMINFO.fields_by_name['offset_in_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERLISTNUMBERRULEITEMINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__number__rule__item__operator__pb2._USERLISTNUMBERRULEITEMOPERATORENUM_USERLISTNUMBERRULEITEMOPERATOR
_USERLISTNUMBERRULEITEMINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_USERLISTSTRINGRULEITEMINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__string__rule__item__operator__pb2._USERLISTSTRINGRULEITEMOPERATORENUM_USERLISTSTRINGRULEITEMOPERATOR
_USERLISTSTRINGRULEITEMINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_COMBINEDRULEUSERLISTINFO.fields_by_name['left_operand'].message_type = _USERLISTRULEINFO
_COMBINEDRULEUSERLISTINFO.fields_by_name['right_operand'].message_type = _USERLISTRULEINFO
_COMBINEDRULEUSERLISTINFO.fields_by_name['rule_operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__combined__rule__operator__pb2._USERLISTCOMBINEDRULEOPERATORENUM_USERLISTCOMBINEDRULEOPERATOR
_DATESPECIFICRULEUSERLISTINFO.fields_by_name['rule'].message_type = _USERLISTRULEINFO
_DATESPECIFICRULEUSERLISTINFO.fields_by_name['start_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DATESPECIFICRULEUSERLISTINFO.fields_by_name['end_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPRESSIONRULEUSERLISTINFO.fields_by_name['rule'].message_type = _USERLISTRULEINFO
_RULEBASEDUSERLISTINFO.fields_by_name['prepopulation_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__prepopulation__status__pb2._USERLISTPREPOPULATIONSTATUSENUM_USERLISTPREPOPULATIONSTATUS
_RULEBASEDUSERLISTINFO.fields_by_name['combined_rule_user_list'].message_type = _COMBINEDRULEUSERLISTINFO
_RULEBASEDUSERLISTINFO.fields_by_name['date_specific_rule_user_list'].message_type = _DATESPECIFICRULEUSERLISTINFO
_RULEBASEDUSERLISTINFO.fields_by_name['expression_rule_user_list'].message_type = _EXPRESSIONRULEUSERLISTINFO
_RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list'].fields.append(
  _RULEBASEDUSERLISTINFO.fields_by_name['combined_rule_user_list'])
_RULEBASEDUSERLISTINFO.fields_by_name['combined_rule_user_list'].containing_oneof = _RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list']
_RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list'].fields.append(
  _RULEBASEDUSERLISTINFO.fields_by_name['date_specific_rule_user_list'])
_RULEBASEDUSERLISTINFO.fields_by_name['date_specific_rule_user_list'].containing_oneof = _RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list']
_RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list'].fields.append(
  _RULEBASEDUSERLISTINFO.fields_by_name['expression_rule_user_list'])
_RULEBASEDUSERLISTINFO.fields_by_name['expression_rule_user_list'].containing_oneof = _RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list']
_LOGICALUSERLISTINFO.fields_by_name['rules'].message_type = _USERLISTLOGICALRULEINFO
_USERLISTLOGICALRULEINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__logical__rule__operator__pb2._USERLISTLOGICALRULEOPERATORENUM_USERLISTLOGICALRULEOPERATOR
_USERLISTLOGICALRULEINFO.fields_by_name['rule_operands'].message_type = _LOGICALUSERLISTOPERANDINFO
_LOGICALUSERLISTOPERANDINFO.fields_by_name['user_list'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BASICUSERLISTINFO.fields_by_name['actions'].message_type = _USERLISTACTIONINFO
_USERLISTACTIONINFO.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTACTIONINFO.fields_by_name['remarketing_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTACTIONINFO.oneofs_by_name['user_list_action'].fields.append(
  _USERLISTACTIONINFO.fields_by_name['conversion_action'])
_USERLISTACTIONINFO.fields_by_name['conversion_action'].containing_oneof = _USERLISTACTIONINFO.oneofs_by_name['user_list_action']
_USERLISTACTIONINFO.oneofs_by_name['user_list_action'].fields.append(
  _USERLISTACTIONINFO.fields_by_name['remarketing_action'])
_USERLISTACTIONINFO.fields_by_name['remarketing_action'].containing_oneof = _USERLISTACTIONINFO.oneofs_by_name['user_list_action']
DESCRIPTOR.message_types_by_name['SimilarUserListInfo'] = _SIMILARUSERLISTINFO
DESCRIPTOR.message_types_by_name['CrmBasedUserListInfo'] = _CRMBASEDUSERLISTINFO
DESCRIPTOR.message_types_by_name['UserListRuleInfo'] = _USERLISTRULEINFO
DESCRIPTOR.message_types_by_name['UserListRuleItemGroupInfo'] = _USERLISTRULEITEMGROUPINFO
DESCRIPTOR.message_types_by_name['UserListRuleItemInfo'] = _USERLISTRULEITEMINFO
DESCRIPTOR.message_types_by_name['UserListDateRuleItemInfo'] = _USERLISTDATERULEITEMINFO
DESCRIPTOR.message_types_by_name['UserListNumberRuleItemInfo'] = _USERLISTNUMBERRULEITEMINFO
DESCRIPTOR.message_types_by_name['UserListStringRuleItemInfo'] = _USERLISTSTRINGRULEITEMINFO
DESCRIPTOR.message_types_by_name['CombinedRuleUserListInfo'] = _COMBINEDRULEUSERLISTINFO
DESCRIPTOR.message_types_by_name['DateSpecificRuleUserListInfo'] = _DATESPECIFICRULEUSERLISTINFO
DESCRIPTOR.message_types_by_name['ExpressionRuleUserListInfo'] = _EXPRESSIONRULEUSERLISTINFO
DESCRIPTOR.message_types_by_name['RuleBasedUserListInfo'] = _RULEBASEDUSERLISTINFO
DESCRIPTOR.message_types_by_name['LogicalUserListInfo'] = _LOGICALUSERLISTINFO
DESCRIPTOR.message_types_by_name['UserListLogicalRuleInfo'] = _USERLISTLOGICALRULEINFO
DESCRIPTOR.message_types_by_name['LogicalUserListOperandInfo'] = _LOGICALUSERLISTOPERANDINFO
DESCRIPTOR.message_types_by_name['BasicUserListInfo'] = _BASICUSERLISTINFO
DESCRIPTOR.message_types_by_name['UserListActionInfo'] = _USERLISTACTIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimilarUserListInfo = _reflection.GeneratedProtocolMessageType('SimilarUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _SIMILARUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """SimilarUserList is a list of users which are similar to users from
  another UserList. These lists are read-only and automatically created by
  Google.
  
  
  Attributes:
      seed_user_list:
          Seed UserList from which this list is derived.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.SimilarUserListInfo)
  ))
_sym_db.RegisterMessage(SimilarUserListInfo)

CrmBasedUserListInfo = _reflection.GeneratedProtocolMessageType('CrmBasedUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _CRMBASEDUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """UserList of CRM users provided by the advertiser.
  
  
  Attributes:
      app_id:
          A string that uniquely identifies a mobile application from
          which the data was collected to the Google Ads API. For iOS,
          the ID string is the 9 digit string that appears at the end of
          an App Store URL (e.g., "476943146" for "Flood-It! 2" whose
          App Store link is http://itunes.apple.com/us/app/flood-
          it!-2/id476943146). For Android, the ID string is the
          application's package name (e.g., "com.labpixies.colordrips"
          for "Color Drips" given Google Play link https://play.google.c
          om/store/apps/details?id=com.labpixies.colordrips). Required
          when creating CrmBasedUserList for uploading mobile
          advertising IDs.
      upload_key_type:
          Matching key type of the list. Mixed data types are not
          allowed on the same list. This field is required for an ADD
          operation.
      data_source_type:
          Data source of the list. Default value is FIRST\_PARTY. Only
          whitelisted customers can create third-party sourced CRM
          lists.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.CrmBasedUserListInfo)
  ))
_sym_db.RegisterMessage(CrmBasedUserListInfo)

UserListRuleInfo = _reflection.GeneratedProtocolMessageType('UserListRuleInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTRULEINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A client defined rule based on custom parameters sent by web sites or
  uploaded by the advertiser.
  
  
  Attributes:
      rule_type:
          Rule type is used to determine how to group rule items.  The
          default is OR of ANDs (disjunctive normal form). That is, rule
          items will be ANDed together within rule item groups and the
          groups themselves will be ORed together.  Currently AND of ORs
          (conjunctive normal form) is only supported for
          ExpressionRuleUserList.
      rule_item_groups:
          List of rule item groups that defines this rule. Rule item
          groups are grouped together based on rule\_type.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListRuleInfo)
  ))
_sym_db.RegisterMessage(UserListRuleInfo)

UserListRuleItemGroupInfo = _reflection.GeneratedProtocolMessageType('UserListRuleItemGroupInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTRULEITEMGROUPINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A group of rule items.
  
  
  Attributes:
      rule_items:
          Rule items that will be grouped together based on rule\_type.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListRuleItemGroupInfo)
  ))
_sym_db.RegisterMessage(UserListRuleItemGroupInfo)

UserListRuleItemInfo = _reflection.GeneratedProtocolMessageType('UserListRuleItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTRULEITEMINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """An atomic rule fragment.
  
  
  Attributes:
      name:
          Rule variable name. It should match the corresponding key name
          fired by the pixel. A name must begin with US-ascii letters or
          underscore or UTF8 code that is greater than 127 and consist
          of US-ascii letters or digits or underscore or UTF8 code that
          is greater than 127. For websites, there are two built-in
          variable URL (name = 'url\_\_') and referrer URL (name =
          'ref\_url\_\_'). This field must be populated when creating a
          new rule item.
      rule_item:
          An atomic rule fragment.
      number_rule_item:
          An atomic rule fragment composed of a number operation.
      string_rule_item:
          An atomic rule fragment composed of a string operation.
      date_rule_item:
          An atomic rule fragment composed of a date operation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListRuleItemInfo)
  ))
_sym_db.RegisterMessage(UserListRuleItemInfo)

UserListDateRuleItemInfo = _reflection.GeneratedProtocolMessageType('UserListDateRuleItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTDATERULEITEMINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A rule item composed of date operation.
  
  
  Attributes:
      operator:
          Date comparison operator. This field is required and must be
          populated when creating new date rule item.
      value:
          String representing date value to be compared with the rule
          variable. Supported date format is YYYY-MM-DD. Times are
          reported in the customer's time zone.
      offset_in_days:
          The relative date value of the right hand side denoted by
          number of days offset from now. The value field will override
          this field when both are present.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListDateRuleItemInfo)
  ))
_sym_db.RegisterMessage(UserListDateRuleItemInfo)

UserListNumberRuleItemInfo = _reflection.GeneratedProtocolMessageType('UserListNumberRuleItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTNUMBERRULEITEMINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A rule item composed of number operation.
  
  
  Attributes:
      operator:
          Number comparison operator. This field is required and must be
          populated when creating a new number rule item.
      value:
          Number value to be compared with the variable. This field is
          required and must be populated when creating a new number rule
          item.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListNumberRuleItemInfo)
  ))
_sym_db.RegisterMessage(UserListNumberRuleItemInfo)

UserListStringRuleItemInfo = _reflection.GeneratedProtocolMessageType('UserListStringRuleItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTSTRINGRULEITEMINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A rule item fragment composed of date operation.
  
  
  Attributes:
      operator:
          String comparison operator. This field is required and must be
          populated when creating a new string rule item.
      value:
          The right hand side of the string rule item. For URLs or
          referrer URLs, the value can not contain illegal URL chars
          such as newlines, quotes, tabs, or parentheses. This field is
          required and must be populated when creating a new string rule
          item.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListStringRuleItemInfo)
  ))
_sym_db.RegisterMessage(UserListStringRuleItemInfo)

CombinedRuleUserListInfo = _reflection.GeneratedProtocolMessageType('CombinedRuleUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _COMBINEDRULEUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """User lists defined by combining two rules, left operand and right
  operand. There are two operators: AND where left operand and right
  operand have to be true; AND\_NOT where left operand is true but right
  operand is false.
  
  
  Attributes:
      left_operand:
          Left operand of the combined rule. This field is required and
          must be populated when creating new combined rule based user
          list.
      right_operand:
          Right operand of the combined rule. This field is required and
          must be populated when creating new combined rule based user
          list.
      rule_operator:
          Operator to connect the two operands.  Required for creating a
          combined rule user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.CombinedRuleUserListInfo)
  ))
_sym_db.RegisterMessage(CombinedRuleUserListInfo)

DateSpecificRuleUserListInfo = _reflection.GeneratedProtocolMessageType('DateSpecificRuleUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _DATESPECIFICRULEUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Visitors of a page during specific dates.
  
  
  Attributes:
      rule:
          Boolean rule that defines visitor of a page.  Required for
          creating a date specific rule user list.
      start_date:
          Start date of users visit. If set to 2000-01-01, then the list
          includes all users before end\_date. The date's format should
          be YYYY-MM-DD.  Required for creating a data specific rule
          user list.
      end_date:
          End date of users visit. If set to 2037-12-30, then the list
          includes all users after start\_date. The date's format should
          be YYYY-MM-DD.  Required for creating a data specific rule
          user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.DateSpecificRuleUserListInfo)
  ))
_sym_db.RegisterMessage(DateSpecificRuleUserListInfo)

ExpressionRuleUserListInfo = _reflection.GeneratedProtocolMessageType('ExpressionRuleUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _EXPRESSIONRULEUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Visitors of a page. The page visit is defined by one boolean rule
  expression.
  
  
  Attributes:
      rule:
          Boolean rule that defines this user list. The rule consists of
          a list of rule item groups and each rule item group consists
          of a list of rule items. All the rule item groups are ORed or
          ANDed together for evaluation based on rule.rule\_type.
          Required for creating an expression rule user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ExpressionRuleUserListInfo)
  ))
_sym_db.RegisterMessage(ExpressionRuleUserListInfo)

RuleBasedUserListInfo = _reflection.GeneratedProtocolMessageType('RuleBasedUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _RULEBASEDUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Representation of a userlist that is generated by a rule.
  
  
  Attributes:
      prepopulation_status:
          The status of pre-population. The field is default to NONE if
          not set which means the previous users will not be considered.
          If set to REQUESTED, past site visitors or app users who match
          the list definition will be included in the list (works on the
          Display Network only). This will only add past users from
          within the last 30 days, depending on the list's membership
          duration and the date when the remarketing tag is added. The
          status will be updated to FINISHED once request is processed,
          or FAILED if the request fails.
      rule_based_user_list:
          Subtypes of rule based user lists.
      combined_rule_user_list:
          User lists defined by combining two rules. There are two
          operators: AND, where the left and right operands have to be
          true; AND\_NOT where left operand is true but right operand is
          false.
      date_specific_rule_user_list:
          Visitors of a page during specific dates. The visiting periods
          are defined as follows: Between start\_date (inclusive) and
          end\_date (inclusive); Before end\_date (exclusive) with
          start\_date = 2000-01-01; After start\_date (exclusive) with
          end\_date = 2037-12-30.
      expression_rule_user_list:
          Visitors of a page. The page visit is defined by one boolean
          rule expression.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.RuleBasedUserListInfo)
  ))
_sym_db.RegisterMessage(RuleBasedUserListInfo)

LogicalUserListInfo = _reflection.GeneratedProtocolMessageType('LogicalUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _LOGICALUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Represents a user list that is a custom combination of user lists.
  
  
  Attributes:
      rules:
          Logical list rules that define this user list. The rules are
          defined as a logical operator (ALL/ANY/NONE) and a list of
          user lists. All the rules are ANDed when they are evaluated.
          Required for creating a logical user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.LogicalUserListInfo)
  ))
_sym_db.RegisterMessage(LogicalUserListInfo)

UserListLogicalRuleInfo = _reflection.GeneratedProtocolMessageType('UserListLogicalRuleInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTLOGICALRULEINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A user list logical rule. A rule has a logical operator (and/or/not) and
  a list of user lists as operands.
  
  
  Attributes:
      operator:
          The logical operator of the rule.
      rule_operands:
          The list of operands of the rule.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListLogicalRuleInfo)
  ))
_sym_db.RegisterMessage(UserListLogicalRuleInfo)

LogicalUserListOperandInfo = _reflection.GeneratedProtocolMessageType('LogicalUserListOperandInfo', (_message.Message,), dict(
  DESCRIPTOR = _LOGICALUSERLISTOPERANDINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Operand of logical user list that consists of a user list.
  
  
  Attributes:
      user_list:
          Resource name of a user list as an operand.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.LogicalUserListOperandInfo)
  ))
_sym_db.RegisterMessage(LogicalUserListOperandInfo)

BasicUserListInfo = _reflection.GeneratedProtocolMessageType('BasicUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _BASICUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """User list targeting as a collection of conversions or remarketing
  actions.
  
  
  Attributes:
      actions:
          Actions associated with this user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.BasicUserListInfo)
  ))
_sym_db.RegisterMessage(BasicUserListInfo)

UserListActionInfo = _reflection.GeneratedProtocolMessageType('UserListActionInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTACTIONINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Represents an action type used for building remarketing user lists.
  
  
  Attributes:
      user_list_action:
          Subtypes of user list action.
      conversion_action:
          A conversion action that's not generated from remarketing.
      remarketing_action:
          A remarketing action.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListActionInfo)
  ))
_sym_db.RegisterMessage(UserListActionInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/operation_access_denied_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/operation_access_denied_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\037OperationAccessDeniedErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\nHgoogle/ads/googleads_v1/proto/errors/operation_access_denied_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xeb\x03\n\x1eOperationAccessDeniedErrorEnum\"\xc8\x03\n\x1aOperationAccessDeniedError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x18\n\x14\x41\x43TION_NOT_PERMITTED\x10\x02\x12\"\n\x1e\x43REATE_OPERATION_NOT_PERMITTED\x10\x03\x12\"\n\x1eREMOVE_OPERATION_NOT_PERMITTED\x10\x04\x12\"\n\x1eUPDATE_OPERATION_NOT_PERMITTED\x10\x05\x12*\n&MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT\x10\x06\x12-\n)OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE\x10\x07\x12#\n\x1f\x43REATE_AS_REMOVED_NOT_PERMITTED\x10\x08\x12\x30\n,OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE\x10\t\x12-\n)OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE\x10\n\x12%\n!MUTATE_NOT_PERMITTED_FOR_CUSTOMER\x10\x0b\x42\xfa\x01\n\"com.google.ads.googleads.v1.errorsB\x1fOperationAccessDeniedErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_OPERATIONACCESSDENIEDERRORENUM_OPERATIONACCESSDENIEDERROR = _descriptor.EnumDescriptor(
  name='OperationAccessDeniedError',
  full_name='google.ads.googleads.v1.errors.OperationAccessDeniedErrorEnum.OperationAccessDeniedError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_NOT_PERMITTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE_OPERATION_NOT_PERMITTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVE_OPERATION_NOT_PERMITTED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_OPERATION_NOT_PERMITTED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE_AS_REMOVED_NOT_PERMITTED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUTATE_NOT_PERMITTED_FOR_CUSTOMER', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=174,
  serialized_end=630,
)
_sym_db.RegisterEnumDescriptor(_OPERATIONACCESSDENIEDERRORENUM_OPERATIONACCESSDENIEDERROR)


_OPERATIONACCESSDENIEDERRORENUM = _descriptor.Descriptor(
  name='OperationAccessDeniedErrorEnum',
  full_name='google.ads.googleads.v1.errors.OperationAccessDeniedErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPERATIONACCESSDENIEDERRORENUM_OPERATIONACCESSDENIEDERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=630,
)

_OPERATIONACCESSDENIEDERRORENUM_OPERATIONACCESSDENIEDERROR.containing_type = _OPERATIONACCESSDENIEDERRORENUM
DESCRIPTOR.message_types_by_name['OperationAccessDeniedErrorEnum'] = _OPERATIONACCESSDENIEDERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OperationAccessDeniedErrorEnum = _reflection.GeneratedProtocolMessageType('OperationAccessDeniedErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONACCESSDENIEDERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.operation_access_denied_error_pb2'
  ,
  __doc__ = """Container for enum describing possible operation access denied errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.OperationAccessDeniedErrorEnum)
  ))
_sym_db.RegisterMessage(OperationAccessDeniedErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Errors used by the Google Ads API library."""


class GoogleAdsException(Exception):
    """Exception thrown in response to an API error from GoogleAds servers."""

    def __init__(self, error, call, failure, request_id):
        """Initializer.

        Args:
            error: the grpc.RpcError raised by an rpc call.
            call: the grpc.Call object containing the details of the rpc call.
            failure: the GoogleAdsFailure instance describing how the
                GoogleAds API call failed.
            request_id: a str request ID associated with the GoogleAds API call.
        """
        self.error = error
        self.call = call
        self.failure = failure
        self.request_id = request_id



# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A gRPC Interceptor that is responsible for handling Google Ads API errors.

This class is initialized in the GoogleAdsClient and passed into a grpc
intercept_channel whenever a new service is initialized. It intercepts requests
to determine if a non-retryable Google Ads API error has been encountered. If
so it translates the error to a GoogleAdsFailure instance and raises it.
"""

from importlib import import_module

from google.protobuf.message import DecodeError
from grpc import UnaryUnaryClientInterceptor, StatusCode

from google.ads.google_ads.errors import GoogleAdsException

from .interceptor_mixin import InterceptorMixin


class ExceptionInterceptor(InterceptorMixin, UnaryUnaryClientInterceptor):
    """An interceptor that wraps rpc exceptions."""

    # Codes that are retried upon by google.api_core.
    _RETRY_STATUS_CODES = (StatusCode.INTERNAL, StatusCode.RESOURCE_EXHAUSTED)

    def __init__(self, api_version):
        """Initializes the ExceptionInterceptor

        Args:
            api_version: a str of the API version of the request.
        """
        self._api_version = api_version
        self._failure_key = (
            'google.ads.googleads.{}.errors.googleadsfailure-bin'.format(
                api_version))

    def _get_google_ads_failure(self, trailing_metadata):
        """Gets the Google Ads failure details if they exist.

        Args:
            trailing_metadata: a tuple of metadatum from the service response.

        Returns:
            A GoogleAdsFailure that describes how a GoogleAds API call failed.
            Returns None if either the trailing metadata of the request did not
            return the failure details, or if the GoogleAdsFailure fails to
            parse.
        """
        if trailing_metadata is not None:
            for kv in trailing_metadata:
                if kv[0] == self._failure_key:
                    try:
                        error_protos = import_module(
                            'google.ads.google_ads.%s.proto.errors' %
                                self._api_version)
                        ga_failure = error_protos.errors_pb2.GoogleAdsFailure()
                        ga_failure.ParseFromString(kv[1])
                        return ga_failure
                    except DecodeError:
                        return None

        return None

    def _handle_grpc_failure(self, response):
        """Attempts to convert failed responses to a GoogleAdsException object.

        Handles failed gRPC responses of by attempting to convert them
        to a more readable GoogleAdsException. Certain types of exceptions are
        not converted; if the object's trailing metadata does not indicate that
        it is a GoogleAdsException, or if it falls under a certain category of
        status code, (INTERNAL or RESOURCE_EXHAUSTED). See documentation for
        more information about gRPC status codes:
        https://github.com/grpc/grpc/blob/master/doc/statuscodes.md

        Args:
            response: a grpc.Call/grpc.Future instance.

        Raises:
            GoogleAdsException: If the exception's trailing metadata
                indicates that it is a GoogleAdsException.
            RpcError: If the exception's is a gRPC exception but the trailing
                metadata is empty or is not indicative of a GoogleAdsException,
                or if the exception has a status code of INTERNAL or
                RESOURCE_EXHAUSTED.
            Exception: If not a GoogleAdsException or RpcException the error
                will be raised as-is.
        """
        status_code = response.code()
        exception = response.exception()

        if status_code not in self._RETRY_STATUS_CODES:
            trailing_metadata = response.trailing_metadata()
            google_ads_failure = self._get_google_ads_failure(trailing_metadata)

            if google_ads_failure:
                request_id = self.get_request_id_from_metadata(trailing_metadata)

                raise GoogleAdsException(exception, response,
                                         google_ads_failure, request_id)
            else:
                # Raise the original exception if not a GoogleAdsFailure.
                raise exception
        else:
            # Raise the original exception if error has status code
            # INTERNAL or RESOURCE_EXHAUSTED.
            raise exception

    def intercept_unary_unary(self, continuation, client_call_details, request):
        """Intercepts and wraps exceptions in the rpc response.

        Overrides abstract method defined in grpc.UnaryUnaryClientInterceptor.

        Returns:
            A grpc.Call instance representing a service response.

        Raises:
            GoogleAdsException: If the exception's trailing metadata
                indicates that it is a GoogleAdsException.
            RpcError: If the exception's trailing metadata is empty or is not
                indicative of a GoogleAdsException, or if the exception has a
                status code of INTERNAL or RESOURCE_EXHAUSTED.
        """
        response = continuation(client_call_details, request)
        exception = response.exception()

        if exception:
            self._handle_grpc_failure(response)
        else:
            return response


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/ad_group_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/ad_group_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\021AdGroupErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n9google/ads/googleads_v1/proto/errors/ad_group_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xa0\x04\n\x10\x41\x64GroupErrorEnum\"\x8b\x04\n\x0c\x41\x64GroupError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1a\n\x16\x44UPLICATE_ADGROUP_NAME\x10\x02\x12\x18\n\x14INVALID_ADGROUP_NAME\x10\x03\x12%\n!ADVERTISER_NOT_ON_CONTENT_NETWORK\x10\x05\x12\x0f\n\x0b\x42ID_TOO_BIG\x10\x06\x12*\n&BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH\x10\x07\x12\x18\n\x14MISSING_ADGROUP_NAME\x10\x08\x12 \n\x1c\x41\x44GROUP_LABEL_DOES_NOT_EXIST\x10\t\x12 \n\x1c\x41\x44GROUP_LABEL_ALREADY_EXISTS\x10\n\x12,\n(INVALID_CONTENT_BID_CRITERION_TYPE_GROUP\x10\x0b\x12\x38\n4AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE\x10\x0c\x12\x39\n5ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY\x10\r\x12\x42\n>CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING\x10\x0e\x42\xec\x01\n\"com.google.ads.googleads.v1.errorsB\x11\x41\x64GroupErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_ADGROUPERRORENUM_ADGROUPERROR = _descriptor.EnumDescriptor(
  name='AdGroupError',
  full_name='google.ads.googleads.v1.errors.AdGroupErrorEnum.AdGroupError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_ADGROUP_NAME', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ADGROUP_NAME', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADVERTISER_NOT_ON_CONTENT_NETWORK', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_TOO_BIG', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_ADGROUP_NAME', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADGROUP_LABEL_DOES_NOT_EXIST', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADGROUP_LABEL_ALREADY_EXISTS', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CONTENT_BID_CRITERION_TYPE_GROUP', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING', index=13, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=145,
  serialized_end=668,
)
_sym_db.RegisterEnumDescriptor(_ADGROUPERRORENUM_ADGROUPERROR)


_ADGROUPERRORENUM = _descriptor.Descriptor(
  name='AdGroupErrorEnum',
  full_name='google.ads.googleads.v1.errors.AdGroupErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADGROUPERRORENUM_ADGROUPERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=668,
)

_ADGROUPERRORENUM_ADGROUPERROR.containing_type = _ADGROUPERRORENUM
DESCRIPTOR.message_types_by_name['AdGroupErrorEnum'] = _ADGROUPERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroupErrorEnum = _reflection.GeneratedProtocolMessageType('AdGroupErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.ad_group_error_pb2'
  ,
  __doc__ = """Container for enum describing possible ad group errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.AdGroupErrorEnum)
  ))
_sym_db.RegisterMessage(AdGroupErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/user_interest.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import criterion_category_availability_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criterion__category__availability__pb2
from google.ads.google_ads.v1.proto.enums import user_interest_taxonomy_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_user__interest__taxonomy__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/user_interest.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\021UserInterestProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n;google/ads/googleads_v1/proto/resources/user_interest.proto\x12!google.ads.googleads.v1.resources\x1aJgoogle/ads/googleads_v1/proto/common/criterion_category_availability.proto\x1a\x45google/ads/googleads_v1/proto/enums/user_interest_taxonomy_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xbd\x03\n\x0cUserInterest\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12k\n\rtaxonomy_type\x18\x02 \x01(\x0e\x32T.google.ads.googleads.v1.enums.UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType\x12\x35\n\x10user_interest_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14user_interest_parent\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\x0flaunched_to_all\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12U\n\x0e\x61vailabilities\x18\x07 \x03(\x0b\x32=.google.ads.googleads.v1.common.CriterionCategoryAvailabilityB\xfe\x01\n%com.google.ads.googleads.v1.resourcesB\x11UserInterestProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criterion__category__availability__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_user__interest__taxonomy__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_USERINTEREST = _descriptor.Descriptor(
  name='UserInterest',
  full_name='google.ads.googleads.v1.resources.UserInterest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.UserInterest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taxonomy_type', full_name='google.ads.googleads.v1.resources.UserInterest.taxonomy_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_interest_id', full_name='google.ads.googleads.v1.resources.UserInterest.user_interest_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.UserInterest.name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_interest_parent', full_name='google.ads.googleads.v1.resources.UserInterest.user_interest_parent', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='launched_to_all', full_name='google.ads.googleads.v1.resources.UserInterest.launched_to_all', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='availabilities', full_name='google.ads.googleads.v1.resources.UserInterest.availabilities', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=753,
)

_USERINTEREST.fields_by_name['taxonomy_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_user__interest__taxonomy__type__pb2._USERINTERESTTAXONOMYTYPEENUM_USERINTERESTTAXONOMYTYPE
_USERINTEREST.fields_by_name['user_interest_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERINTEREST.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERINTEREST.fields_by_name['user_interest_parent'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERINTEREST.fields_by_name['launched_to_all'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERINTEREST.fields_by_name['availabilities'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criterion__category__availability__pb2._CRITERIONCATEGORYAVAILABILITY
DESCRIPTOR.message_types_by_name['UserInterest'] = _USERINTEREST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserInterest = _reflection.GeneratedProtocolMessageType('UserInterest', (_message.Message,), dict(
  DESCRIPTOR = _USERINTEREST,
  __module__ = 'google.ads.googleads_v1.proto.resources.user_interest_pb2'
  ,
  __doc__ = """A user interest: a particular interest-based vertical to be targeted.
  
  
  Attributes:
      resource_name:
          The resource name of the user interest. User interest resource
          names have the form:
          ``customers/{customer_id}/userInterests/{user_interest_id}``
      taxonomy_type:
          Taxonomy type of the user interest.
      user_interest_id:
          The ID of the user interest.
      name:
          The name of the user interest.
      user_interest_parent:
          The parent of the user interest.
      launched_to_all:
          True if the user interest is launched to all channels and
          locales.
      availabilities:
          Availability information of the user interest.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.UserInterest)
  ))
_sym_db.RegisterMessage(UserInterest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/user_list_size_range.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/user_list_size_range.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\026UserListSizeRangeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\n>google/ads/googleads_v2/proto/enums/user_list_size_range.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\x94\x05\n\x15UserListSizeRangeEnum\"\xfa\x04\n\x11UserListSizeRange\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1a\n\x16LESS_THAN_FIVE_HUNDRED\x10\x02\x12\x1a\n\x16LESS_THAN_ONE_THOUSAND\x10\x03\x12 \n\x1cONE_THOUSAND_TO_TEN_THOUSAND\x10\x04\x12\"\n\x1eTEN_THOUSAND_TO_FIFTY_THOUSAND\x10\x05\x12*\n&FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND\x10\x06\x12\x32\n.ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND\x10\x07\x12\x33\n/THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND\x10\x08\x12(\n$FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION\x10\t\x12\x1e\n\x1aONE_MILLION_TO_TWO_MILLION\x10\n\x12 \n\x1cTWO_MILLION_TO_THREE_MILLION\x10\x0b\x12!\n\x1dTHREE_MILLION_TO_FIVE_MILLION\x10\x0c\x12\x1f\n\x1b\x46IVE_MILLION_TO_TEN_MILLION\x10\r\x12!\n\x1dTEN_MILLION_TO_TWENTY_MILLION\x10\x0e\x12$\n TWENTY_MILLION_TO_THIRTY_MILLION\x10\x0f\x12#\n\x1fTHIRTY_MILLION_TO_FIFTY_MILLION\x10\x10\x12\x16\n\x12OVER_FIFTY_MILLION\x10\x11\x42\xeb\x01\n!com.google.ads.googleads.v2.enumsB\x16UserListSizeRangeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_USERLISTSIZERANGEENUM_USERLISTSIZERANGE = _descriptor.EnumDescriptor(
  name='UserListSizeRange',
  full_name='google.ads.googleads.v2.enums.UserListSizeRangeEnum.UserListSizeRange',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_FIVE_HUNDRED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_ONE_THOUSAND', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONE_THOUSAND_TO_TEN_THOUSAND', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEN_THOUSAND_TO_FIFTY_THOUSAND', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONE_MILLION_TO_TWO_MILLION', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TWO_MILLION_TO_THREE_MILLION', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THREE_MILLION_TO_FIVE_MILLION', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIVE_MILLION_TO_TEN_MILLION', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEN_MILLION_TO_TWENTY_MILLION', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TWENTY_MILLION_TO_THIRTY_MILLION', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIRTY_MILLION_TO_FIFTY_MILLION', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OVER_FIFTY_MILLION', index=17, number=17,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=154,
  serialized_end=788,
)
_sym_db.RegisterEnumDescriptor(_USERLISTSIZERANGEENUM_USERLISTSIZERANGE)


_USERLISTSIZERANGEENUM = _descriptor.Descriptor(
  name='UserListSizeRangeEnum',
  full_name='google.ads.googleads.v2.enums.UserListSizeRangeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERLISTSIZERANGEENUM_USERLISTSIZERANGE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=788,
)

_USERLISTSIZERANGEENUM_USERLISTSIZERANGE.containing_type = _USERLISTSIZERANGEENUM
DESCRIPTOR.message_types_by_name['UserListSizeRangeEnum'] = _USERLISTSIZERANGEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserListSizeRangeEnum = _reflection.GeneratedProtocolMessageType('UserListSizeRangeEnum', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTSIZERANGEENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.user_list_size_range_pb2'
  ,
  __doc__ = """Size range in terms of number of users of a UserList.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.UserListSizeRangeEnum)
  ))
_sym_db.RegisterMessage(UserListSizeRangeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/media_file_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/media_file_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\023MediaFileErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n;google/ads/googleads_v2/proto/errors/media_file_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\x97\x06\n\x12MediaFileErrorEnum\"\x80\x06\n\x0eMediaFileError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1f\n\x1b\x43\x41NNOT_CREATE_STANDARD_ICON\x10\x02\x12\x30\n,CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES\x10\x03\x12)\n%CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA\x10\x04\x12\x13\n\x0f\x44UPLICATE_MEDIA\x10\x05\x12\x0f\n\x0b\x45MPTY_FIELD\x10\x06\x12\'\n#RESOURCE_REFERENCED_IN_MULTIPLE_OPS\x10\x07\x12*\n&FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE\x10\x08\x12\x19\n\x15INVALID_MEDIA_FILE_ID\x10\t\x12\x1a\n\x16INVALID_MEDIA_SUB_TYPE\x10\n\x12\x1b\n\x17INVALID_MEDIA_FILE_TYPE\x10\x0b\x12\x15\n\x11INVALID_MIME_TYPE\x10\x0c\x12\x18\n\x14INVALID_REFERENCE_ID\x10\r\x12\x17\n\x13INVALID_YOU_TUBE_ID\x10\x0e\x12!\n\x1dMEDIA_FILE_FAILED_TRANSCODING\x10\x0f\x12\x18\n\x14MEDIA_NOT_TRANSCODED\x10\x10\x12-\n)MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE\x10\x11\x12\x17\n\x13NO_FIELDS_SPECIFIED\x10\x12\x12\"\n\x1eNULL_REFERENCE_ID_AND_MEDIA_ID\x10\x13\x12\x0c\n\x08TOO_LONG\x10\x14\x12\x14\n\x10UNSUPPORTED_TYPE\x10\x15\x12 \n\x1cYOU_TUBE_SERVICE_UNAVAILABLE\x10\x16\x12,\n(YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION\x10\x17\x12\x1c\n\x18YOU_TUBE_VIDEO_NOT_FOUND\x10\x18\x42\xee\x01\n\"com.google.ads.googleads.v2.errorsB\x13MediaFileErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_MEDIAFILEERRORENUM_MEDIAFILEERROR = _descriptor.EnumDescriptor(
  name='MediaFileError',
  full_name='google.ads.googleads.v2.errors.MediaFileErrorEnum.MediaFileError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_STANDARD_ICON', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_MEDIA', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMPTY_FIELD', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_REFERENCED_IN_MULTIPLE_OPS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MEDIA_FILE_ID', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MEDIA_SUB_TYPE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MEDIA_FILE_TYPE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MIME_TYPE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REFERENCE_ID', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_YOU_TUBE_ID', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_FILE_FAILED_TRANSCODING', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_NOT_TRANSCODED', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_FIELDS_SPECIFIED', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NULL_REFERENCE_ID_AND_MEDIA_ID', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_LONG', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_TYPE', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOU_TUBE_SERVICE_UNAVAILABLE', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOU_TUBE_VIDEO_NOT_FOUND', index=24, number=24,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=149,
  serialized_end=917,
)
_sym_db.RegisterEnumDescriptor(_MEDIAFILEERRORENUM_MEDIAFILEERROR)


_MEDIAFILEERRORENUM = _descriptor.Descriptor(
  name='MediaFileErrorEnum',
  full_name='google.ads.googleads.v2.errors.MediaFileErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MEDIAFILEERRORENUM_MEDIAFILEERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=917,
)

_MEDIAFILEERRORENUM_MEDIAFILEERROR.containing_type = _MEDIAFILEERRORENUM
DESCRIPTOR.message_types_by_name['MediaFileErrorEnum'] = _MEDIAFILEERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaFileErrorEnum = _reflection.GeneratedProtocolMessageType('MediaFileErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAFILEERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.media_file_error_pb2'
  ,
  __doc__ = """Container for enum describing possible media file errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.MediaFileErrorEnum)
  ))
_sym_db.RegisterMessage(MediaFileErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/date_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/date_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\016DateErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n5google/ads/googleads_v1/proto/errors/date_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xbf\x03\n\rDateErrorEnum\"\xad\x03\n\tDateError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12 \n\x1cINVALID_FIELD_VALUES_IN_DATE\x10\x02\x12%\n!INVALID_FIELD_VALUES_IN_DATE_TIME\x10\x03\x12\x17\n\x13INVALID_STRING_DATE\x10\x04\x12#\n\x1fINVALID_STRING_DATE_TIME_MICROS\x10\x06\x12$\n INVALID_STRING_DATE_TIME_SECONDS\x10\x0b\x12\x30\n,INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET\x10\x0c\x12\x1d\n\x19\x45\x41RLIER_THAN_MINIMUM_DATE\x10\x07\x12\x1b\n\x17LATER_THAN_MAXIMUM_DATE\x10\x08\x12\x33\n/DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE\x10\t\x12\x32\n.DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL\x10\nB\xe9\x01\n\"com.google.ads.googleads.v1.errorsB\x0e\x44\x61teErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_DATEERRORENUM_DATEERROR = _descriptor.EnumDescriptor(
  name='DateError',
  full_name='google.ads.googleads.v1.errors.DateErrorEnum.DateError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FIELD_VALUES_IN_DATE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FIELD_VALUES_IN_DATE_TIME', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STRING_DATE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STRING_DATE_TIME_MICROS', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STRING_DATE_TIME_SECONDS', index=6, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET', index=7, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EARLIER_THAN_MINIMUM_DATE', index=8, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LATER_THAN_MAXIMUM_DATE', index=9, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE', index=10, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL', index=11, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=138,
  serialized_end=567,
)
_sym_db.RegisterEnumDescriptor(_DATEERRORENUM_DATEERROR)


_DATEERRORENUM = _descriptor.Descriptor(
  name='DateErrorEnum',
  full_name='google.ads.googleads.v1.errors.DateErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATEERRORENUM_DATEERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=567,
)

_DATEERRORENUM_DATEERROR.containing_type = _DATEERRORENUM
DESCRIPTOR.message_types_by_name['DateErrorEnum'] = _DATEERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DateErrorEnum = _reflection.GeneratedProtocolMessageType('DateErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _DATEERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.date_error_pb2'
  ,
  __doc__ = """Container for enum describing possible date errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.DateErrorEnum)
  ))
_sym_db.RegisterMessage(DateErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
